==> copilot-24.4.10-sources.jar: com/vaadin/copilot/ide/CopilotIDEPluginProperties.java <==
package com.vaadin.copilot.ide;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Properties;

public class CopilotIDEPluginProperties {

    private static final String PORT_PROPERTY = "port";

    private static final String ENDPOINT_PROPERTY = "endpoint";

    private static final String IDE_PROPERTY = "ide";

    private static final String VERSION_PROPERTY = "version";

    private static final String SUPPORTED_ACTIONS_PROPERTY = "supportedActions";

    private final Properties props;

    CopilotIDEPluginProperties(File file) {
        props = new Properties();
        try (FileReader propsReader = new FileReader(file)) {
            props.load(propsReader);
        } catch (IOException ex) {
            getLogger().warn("Cannot load plugin properties");
        }
    }

    int getPort() {
        return Integer.parseInt(props.getProperty(PORT_PROPERTY));
    }

    String getEndpoint() {
        return props.getProperty(ENDPOINT_PROPERTY);
    }

    String getIde() {
        return props.getProperty(IDE_PROPERTY);
    }

    String getVersion() {
        return props.getProperty(VERSION_PROPERTY);
    }

    List<String> getSupportedActions() {
        String actions = props.getProperty(SUPPORTED_ACTIONS_PROPERTY);
        return actions != null ? Arrays.stream(actions.split(",")).toList()
                : Collections.emptyList();
    }

    private static Logger getLogger() {
        return LoggerFactory.getLogger(CopilotIDEPlugin.class);
    }

}

==> copilot-24.4.20-sources.jar: com/vaadin/copilot/ide/CopilotIDEPluginProperties.java <==
package com.vaadin.copilot.ide;

import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Properties;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class CopilotIDEPluginProperties {

    private static final String PORT_PROPERTY = "port";

    private static final String ENDPOINT_PROPERTY = "endpoint";

    private static final String IDE_PROPERTY = "ide";

    private static final String VERSION_PROPERTY = "version";

    private static final String SUPPORTED_ACTIONS_PROPERTY = "supportedActions";

    private final Properties props;

    CopilotIDEPluginProperties(File file) {
        props = new Properties();
        try (FileReader propsReader = new FileReader(file)) {
            props.load(propsReader);
        } catch (IOException ex) {
            getLogger().warn("Cannot load plugin properties");
        }
    }

    int getPort() {
        return Integer.parseInt(props.getProperty(PORT_PROPERTY));
    }

    String getEndpoint() {
        return props.getProperty(ENDPOINT_PROPERTY);
    }

    String getIde() {
        return props.getProperty(IDE_PROPERTY);
    }

    String getVersion() {
        return props.getProperty(VERSION_PROPERTY);
    }

    List<String> getSupportedActions() {
        String actions = props.getProperty(SUPPORTED_ACTIONS_PROPERTY);
        return actions != null ? Arrays.stream(actions.split(",")).toList() : Collections.emptyList();
    }

    private static Logger getLogger() {
        return LoggerFactory.getLogger(CopilotIDEPlugin.class);
    }
}
